@@ -368,15 +368,18 @@ class MainWindow(QMainWindow,Ui_MainWindow):
         info = QAction(QIcon(''), '关于', self)
         self.toolBar.addAction(info)
         info.triggered.connect(self.showabout)
-        exitAct = QAction(QIcon(''), '模型文件夹', self)
-        self.toolBar.addAction(exitAct)
+        #exitAct = QAction(QIcon(''), '终端', self)
+        #self.toolBar.addAction(exitAct)
         exitAct1 = QAction(QIcon(''), '信息窗口', self)
         self.toolBar.addAction(exitAct1)
         exitAct2 = QAction(QIcon(''), 'Tensorboard', self)
         self.toolBar.addAction(exitAct2)
-        exitAct.triggered.connect(self.openmodelFile)
+        exitAct3 = QAction(QIcon(''), 'LabelImg标注工具', self)
+        self.toolBar.addAction(exitAct3)
+        exitAct.triggered.connect(self.opencmd)
         exitAct1.triggered.connect(self.openmsg)
         exitAct2.triggered.connect(self.openTensorboard)
+        exitAct3.triggered.connect(self.openLabelImg)
 
         #终端窗口
         self.w = Window()
@@ -480,6 +483,10 @@ class MainWindow(QMainWindow,Ui_MainWindow):
         #测试模型
         self.pushButton_6.clicked.connect(self.test_classimg_bt)
 
+    def openLabelImg(self):
+        cmd='labelimg2'
+        self.res = subprocess.Popen(cmd)
+        
     def showabout(self):
         self.about=AboutWindow()
         self.about.show()
